dot-list.rules.party_safe: Get Split Variable Names from a partykit Tree (Internal)

.list.rules.party_safeR Documentation

Get Split Variable Names from a partykit Tree (Internal)

Description

Extracts the names of the variables used in the splits of a tree object.

Usage

.list.rules.party_safe(tree)

Arguments

tree

A partykit tree object.

Value

A character vector of unique variable names used in splits.


TemporalForest documentation built on Dec. 23, 2025, 1:06 a.m.