View source: R/temporal_forest_functions.R
| TemporalTree_time | R Documentation |
This is the internal workhorse function called by the temporal_forest wrapper.
It is not intended for direct use by end-users.
TemporalTree_time(
data,
A_combined,
fixed_regress = NULL,
fixed_split = NULL,
var_select = NULL,
cluster = NULL,
maxdepth_factor_screen = 0.04,
maxdepth_factor_select = 0.5,
use_fuzzy = TRUE,
minsize_multiplier = 1,
alpha_screen = 0.2,
alpha_select = 0.05,
alpha_predict = 0.05,
minClusterSize = 4,
n_boot_screen = 50,
keep_fraction_screen = 0.2,
n_boot_select = 100,
number_selected_final = 10
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.