| .list.rules.party_safe | R Documentation |
Extracts the names of the variables used in the splits of a tree object.
.list.rules.party_safe(tree)
tree |
A partykit tree object. |
A character vector of unique variable names used in splits.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.